@@ -96,6 +96,13 @@ class ContextProvider(ABC):
             return ContentBlock(self.name, self._cached_content)
         return None
 
+    def __add__(self, other):
+        if isinstance(other, Message):
+            # Create a new message of the same type as `other`, with `self` prepended.
+            new_items = [self] + other.provider()
+            return type(other)(*new_items)
+        return NotImplemented
+
 class Texts(ContextProvider):
     def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: Optional[str] = None, visible: bool = True):
         if text is None and name is None:
@@ -308,6 +315,8 @@ class Message(ABC):
         self.role = role
         processed_items = []
         for item in initial_items:
+            if item is None:
+                continue
             if isinstance(item, str):
                 # Check if the string contains placeholders from f-string rendering
                 import re
@@ -450,11 +459,33 @@ class Message(ABC):
         return len(self._items)
 
     def __repr__(self): return f"Message(role='{self.role}', items={[i.name for i in self._items]})"
+
+    def __contains__(self, item: Any) -> bool:
+        """Checks if a ContextProvider is in the message."""
+        if not isinstance(item, ContextProvider):
+            return False
+        # The `in` operator on a list checks for equality,
+        # and our custom __eq__ on ContextProvider handles the comparison logic.
+        return item in self._items
+
+    def has(self, provider_type: type) -> bool:
+        """Checks if the message contains a provider of a specific type."""
+        if not isinstance(provider_type, type) or not issubclass(provider_type, ContextProvider):
+            raise TypeError("provider_type must be a subclass of ContextProvider")
+        return any(isinstance(p, provider_type) for p in self._items)
+
     def __bool__(self) -> bool:
         return bool(self._items)
     def get(self, key: str, default: Any = None) -> Any:
         """提供类似字典的 .get() 方法来访问属性。"""
         return getattr(self, key, default)
+
+    async def render_latest(self) -> Optional[Dict[str, Any]]:
+        """Refreshes all providers in the message and returns the rendered dictionary."""
+        tasks = [provider.refresh() for provider in self._items]
+        await asyncio.gather(*tasks)
+        return self.to_dict()
+
     def to_dict(self) -> Optional[Dict[str, Any]]:
         is_multimodal = any(isinstance(p, Images) for p in self._items)
 
@@ -665,30 +696,58 @@ class Messages:
             return Messages(*self._messages[index])
         return self._messages[index]
 
-    def __setitem__(self, index: slice, value: 'Messages'):
-        if not isinstance(index, slice) or not isinstance(value, Messages):
-            raise TypeError("Unsupported operand type(s) for slice assignment")
+    def __setitem__(self, index: Union[int, slice], value: Union[Message, 'Messages']):
+        if isinstance(index, int):
+            if not isinstance(value, Message):
+                raise TypeError("When assigning to an index, the value must be a Message.")
 
-        # Basic slice assignment logic.
-        # A more robust implementation would handle step and negative indices.
-        start, stop, step = index.indices(len(self._messages))
+            if not (-len(self._messages) <= index < len(self._messages)):
+                raise IndexError("Messages assignment index out of range")
 
-        if step != 1:
-            raise ValueError("Slice assignment with step is not supported.")
-
-        # Remove old providers from the index
-        for i in range(start, stop):
-            for provider in self._messages[i].provider():
+            # Get old message to remove its providers
+            old_message = self._messages[index]
+            for provider in old_message.provider():
                 self._notify_provider_removed(provider)
 
-        # Replace the slice in the list
-        self._messages[start:stop] = value._messages
+            # Assign new message
+            self._messages[index] = value
+            value._parent_messages = self
+            for provider in value.provider():
+                self._notify_provider_added(provider, value)
 
-        # Add new providers to the index and set parent
-        for msg in value:
-            msg._parent_messages = self
-            for provider in msg.provider():
-                self._notify_provider_added(provider, msg)
+        elif isinstance(index, slice):
+            if not isinstance(value, Messages):
+                raise TypeError("When assigning to a slice, the value must be a Messages object.")
+
+            start, stop, step = index.indices(len(self._messages))
+            if step != 1:
+                raise ValueError("Slice assignment with step is not supported.")
+
+            # Remove old providers from the index
+            for i in range(start, stop):
+                for provider in self._messages[i].provider():
+                    self._notify_provider_removed(provider)
+
+            # Replace the slice in the list
+            self._messages[start:stop] = value._messages
+
+            # Add new providers to the index and set parent
+            for msg in value:
+                msg._parent_messages = self
+                for provider in msg.provider():
+                    self._notify_provider_added(provider, msg)
+        else:
+            raise TypeError("Unsupported operand type(s) for assignment")
 
     def __len__(self) -> int: return len(self._messages)
     def __iter__(self): return iter(self._messages)
+
+    def __contains__(self, item: Any) -> bool:
+        """Checks if a Message or ContextProvider is in the collection."""
+        if isinstance(item, Message):
+            # Check for object identity
+            return any(item is msg for msg in self._messages)
+        if isinstance(item, ContextProvider):
+            # Check if any message contains the provider
+            return any(item in msg for msg in self._messages)
+        return False
