@@ -1341,6 +1341,145 @@ Files: {Files(visible=True, name="files")}
             if os.path.exists(test_file_path):
                 os.remove(test_file_path)
 
+    async def test_zg_provider_plus_message_addition(self):
+        """测试所有 ContextProvider 子类与 Message 子类相加的功能"""
+        # 1. 准备 providers
+        text_provider = Texts("Some text.")
+        tools_provider = Tools([{"name": "a_tool"}])
+
+        test_file = "test_provider_addition.txt"
+        with open(test_file, "w") as f: f.write("File content.")
+        files_provider = Files(test_file)
+
+        providers_to_test = [text_provider, tools_provider, files_provider]
+
+        # 2. 准备 message aclsdd
+        messages_to_test = [
+            UserMessage(Texts("Initial user message.")),
+            SystemMessage(Texts("Initial system message.")),
+            AssistantMessage(Texts("Initial assistant message."))
+        ]
+
+        try:
+            for provider in providers_to_test:
+                for message in messages_to_test:
+                    with self.subTest(provider=type(provider).__name__, message=type(message).__name__):
+                        # 执行加法操作
+                        result_message = provider + message
+
+                        # 验证结果类型是否与原始 message 相同
+                        self.assertIsInstance(result_message, type(message), f"结果应为 {type(message).__name__} 类型")
+
+                        # 验证 provider 数量
+                        self.assertEqual(len(result_message), 2, "结果消息应包含两个 provider")
+
+                        # 验证 provider 的类型和顺序
+                        result_providers = result_message.provider()
+                        self.assertIsInstance(result_providers[0], type(provider), f"第一个 provider 应为 {type(provider).__name__} 类型")
+                        self.assertIsInstance(result_providers[1], Texts, "第二个 provider 应为 Texts 类型")
+
+                        # 验证原始消息没有被修改
+                        self.assertEqual(len(message), 1)
+
+        finally:
+            # 3. 清理文件
+            if os.path.exists(test_file):
+                os.remove(test_file)
+
+    async def test_zh_provider_plus_message_assignment(self):
+        """测试 ContextProvider + Message 的结果可以赋值回 Messages 列表"""
+        # 1. 准备 provider 和 messages
+        text_provider = Texts("Prefix text.")
+        messages = Messages(
+            UserMessage("Initial user message.")
+        )
+
+        # 2. 执行操作
+        # 这行代码在修改 __setitem__ 之前应该会失败
+        messages[0] = text_provider + messages[0]
+
+        # 3. 验证结果
+        self.assertEqual(len(messages), 1)
+        self.assertEqual(len(messages[0]), 2) # Now UserMessage has two providers
+
+        # 4. 验证内容
+        rendered = await messages.render_latest()
+        self.assertEqual(rendered[0]['content'], "Prefix text.Initial user message.")
+
+        # 5. 验证 provider 索引
+        self.assertIsNotNone(messages.provider(text_provider.name))
+
+    async def test_zi_provider_in_message_and_messages(self):
+        """测试 `in` 操作符是否能检查 provider 是否存在于 Message 或 Messages 中"""
+        # 1. 准备 providers 和 messages
+        text_hi = Texts("hi")
+        text_hello = Texts("hello")
+        text_world = Texts("world")
+
+        message = UserMessage(text_hello, text_hi)
+        messages_collection = Messages(SystemMessage("System"), message)
+
+        # 2. 测试 `in` Message
+        self.assertTrue(Texts("hi") in UserMessage(Texts("hello"), Texts("hi")))
+        self.assertTrue(text_hi in message)
+        self.assertTrue(text_hello in message)
+        self.assertFalse(text_world in message)
+
+        # 3. 测试 `in` Messages
+        self.assertTrue(text_hi in messages_collection)
+        self.assertTrue(text_hello in messages_collection)
+        self.assertFalse(text_world in messages_collection)
+
+        # 4. 测试一个 Message 对象是否在 Messages 中
+        self.assertTrue(message in messages_collection)
+        self.assertFalse(UserMessage("not in collection") in messages_collection)
+
+    async def test_zz_none_input_ignored(self):
+        """测试在Message初始化时，None值是否被自动忽略"""
+        # 1. 在初始化列表中包含 None
+        message = UserMessage("Hello", None, "World")
+        self.assertEqual(len(message.provider()), 2)
+        self.assertIsInstance(message.provider()[0], Texts)
+        self.assertIsInstance(message.provider()[1], Texts)
+        rendered = await message.render_latest()
+        self.assertEqual(rendered['content'], "HelloWorld")
+
+        # 2. 测试只有 None
+        message_none = SystemMessage(None)
+        self.assertEqual(len(message_none.provider()), 0)
+        self.assertFalse(message_none)
+
+        # 3. 测试混合 provider 和 None
+        message_mixed = SystemMessage(Texts("hi"), None)
+        self.assertEqual(len(message_mixed.provider()), 1)
+        self.assertIsInstance(message_mixed.provider()[0], Texts)
+
+    async def test_zaa_has_method_for_provider_type_check(self):
+        """测试 Message.has(type) 方法是否能正确检查 provider 类型"""
+        # 1. 创建一个混合类型的消息
+        message_with_text = UserMessage(Texts("hi"), Images("url"))
+
+        # 2. 测试存在的情况
+        # This line is expected to fail with an AttributeError before implementation
+        self.assertTrue(message_with_text.has(Texts))
+        self.assertTrue(message_with_text.has(Images))
+
+        # 3. 测试不存在的情况
+        self.assertFalse(message_with_text.has(Tools))
+
+        # 4. 测试空消息
+        empty_message = UserMessage()
+        self.assertFalse(empty_message.has(Texts))
+
+        # 5. 测试传入无效类型
+        with self.assertRaises(TypeError):
+            message_with_text.has(str)
+
+        with self.assertRaises(TypeError):
+            # Also test with a class that is not a subclass of ContextProvider
+            class NotAProvider: pass
+            message_with_text.has(NotAProvider)
+
 
 # ==============================================================================
 # 6. 演示
